@@ -1,7 +1,7 @@
 package Display::Resolution;
 
-our $DATE = '2016-10-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-04-26'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -18,100 +18,119 @@ our %SPEC;
 
 our $size_re = qr/\A(\d+)\s*[x*]\s*(\d+)\z/;
 
+# sorted by horizontal pixel size, then vertical size, then name
 our %res_sizes = (
     'QQVGA'     => '160x120', # one fourth QVGA
     'qqVGA'     => '160x120',
 
     'HQVGA'     => '240x160', # half QVGA
 
+    'CGA1'      => '320x200',
     'QVGA'      => '320x240', # one quarter VGA
 
-    'WQVGA'     => '400x240',
+    'WQVGA'     => '400x240', # XXX there are actually variants of WQVGA, apple's ipod nano 7G's WQVGA is 432x240, etc.
+    'qSVGA'     => '400x300', # quarter SVGA
 
-    # XXX there are actually variants of HVGA, e.g. 480x270, 640x240, ...
-    'HVGA'      => '480x320', # half VGA
+    'HVGA'      => '480x320', # half VGA. XXX there are actually variants of HVGA, e.g. 480x270, 640x240, ...
 
-    'VGA'       => '640x480',
+    'CGA2'      => '640x200',
+    'EGA'       => '640x350',
+    'MCGA'      => '640x480',
     'SD'        => '640x480',
+    'VGA'       => '640x480',
 
+    'HGC'       => '720x348',
+    'MDA'       => '720x350',
     '480p'      => '720x480',
 
-    'WVGA'      => '768x480',
     'WGA'       => '768x480',
-
-    'FWVGA'     => '854x480',
-
+    'WVGA'      => '768x480',
     '576p'      => '720x576',
 
-    'qHD'       => '960x540', # one quarter of full HD
-
     'SVGA'      => '800x600',
     'UVGA'      => '800x600',
 
-    # XXX WSVGA also has resolution 1024x576
-    'WSVGA'     => '1024x600',
+    'FWVGA'     => '854x480',
 
     'DGA'       => '960x640', # double-size vga
+    'DVGA'      => '960x640', # double-size vga
+    'qHD'       => '960x540', # one quarter of full HD
 
-    'HD'        => '1280x720',
-    '720p'      => '1280x720',
-    'WXGA 16:9' => '1280x720',
-
+    'WSVGA'     => '1024x600', # XXX WSVGA also has resolution 1024x576
     'XGA'       => '1024x768',
 
-    'WXGA 5:3'  => '1280x768',
-
-    'WXGA 16:10'=> '1280x800',
+    '720p'      => '1280x720',
+    'HD'        => '1280x720',
+    'WXGA 16:9' => '1280x720',
+    'SXGA'      => '1280x1024',
 
     'XGA+'      => '1152x864',
 
+    'WXGA 5:3'  => '1280x768',
+    'WXGA 16:10'=> '1280x800',
+
     'WXGA+'     => '1440x900',
 
     'HD+'       => '1600x900',
-
-    'SXGA'      => '1280x1024',
-
-    'Full HD'   => '1920x1080',
-    'FHD'       => '1920x1080',
-    '1080p'     => '1920x1080',
-
-    'DCI 2K'    => '2048x1080',
-    'Cinema 2K' => '2048x1080',
-
     'UXGA'      => '1600x1200',
 
+    '1080p'     => '1920x1080',
+    'FHD'       => '1920x1080',
+    'Full HD'   => '1920x1080',
     'WUXGA'     => '1920x1200',
 
+    'Cinema 2K' => '2048x1080',
+    'DCI 2K'    => '2048x1080',
+
+    '1440p'     => '2560x1440',
     'QHD'       => '2560x1440', # four times HD
     'WQHD'      => '2560x1440',
-    '1440p'     => '2560x1440',
+    'WQXGA'     => '2560x1600',
+
+    'QSXGA+'    => '2800x2100',
 
     'UWQHD'     => '3440x1440',
 
-    'WQXGA'     => '2560x1600',
-
-    'WQXGA+'    => '3200x1800',
     'QHD+'      => '3200x1800',
+    'WQXGA+'    => '3200x1800',
+    'WQSXGA'    => '3200x2048',
+    'QUXGA'     => '3200x2400',
 
-    'UHD 4K'    => '3840x2160',
-    '4K UHD'    => '3840x2160',
-    'UHDTV-1'   => '3840x2160',
+    'UW4K'      => '3840x1600',
+    '2160p'     => '3840x2160',
     '4K'        => '3840x2160',
+    '4K UHD'    => '3840x2160',
+    '4K UHD-1'  => '3840x2160',
+    'UHD 4K'    => '3840x2160',
+    'UHDTV-1'   => '3840x2160',
+    'WQUXGA'    => '3840x2400',
 
-    'DCI 4K'    => '4096x2160',
     'Cinema 4K' => '4096x2160',
+    'DCI 4K'    => '4096x2160',
+    'HXGA'      => '4096x3072',
 
-    'UHD+'      => '5120x2880',
+    'UW5K'      => '5120x2160',
     '5K'        => '5120x2880',
+    'UHD+'      => '5120x2880',
+    'WHXGA'     => '5120x3200',
+    'HSXGA'     => '5120x4096',
 
-    'UHD 8K'    => '7680x4320',
-    '8K UHD'    => '7680x4320',
-    'UHDTV-2'   => '7680x4320',
+    'WHSXGA'    => '6400x4096',
+    'HUXGA'     => '6400x4800',
+
+    '4320p'     => '7680x4320',
     '8K'        => '7680x4320',
+    '8K UHD'    => '7680x4320',
+    '8K UHD-2'  => '7680x4320',
+    'UHD 8K'    => '7680x4320',
+    'UHDTV-2'   => '7680x4320',
+    'WHUXGA'    => '7680x4800',
+
+    'UW10K'     => '10240x4320',
 
-    'UHD 16K'   => '15360x8640',
-    '16K UHD'   => '15360x8640',
     '16K'       => '15360x8640',
+    '16K UHD'   => '15360x8640',
+    'UHD 16K'   => '15360x8640',
 );
 
 my @res_names = sort keys %res_sizes;
@@ -302,12 +321,16 @@ Display::Resolution - Convert between display resolution size (e.g. 1280x720) an
 
 =head1 VERSION
 
-This document describes version 0.002 of Display::Resolution (from Perl distribution Display-Resolution), released on 2016-10-07.
+This document describes version 0.003 of Display::Resolution (from Perl distribution Display-Resolution), released on 2018-04-26.
 
 =head1 FUNCTIONS
 
 
-=head2 get_display_resolution_name(%args) -> str|array[str]
+=head2 get_display_resolution_name
+
+Usage:
+
+ get_display_resolution_name(%args) -> str|array[str]
 
 Get the known name for a display resolution size.
 
@@ -317,19 +340,19 @@ Examples:
 
 =item * You can specify width and height ...:
 
- get_display_resolution_name(height => 480, width => 640); # -> "SD"
+ get_display_resolution_name(height => 480, width => 640); # -> [200, "OK", "MCGA", {}]
 
 =item * ... or size directly (in "x x y" or "x*y" format):
 
- get_display_resolution_name(size => "1280x720"); # -> "720p"
+ get_display_resolution_name(size => "1280x720"); # -> [200, "OK", "720p", {}]
 
 =item * Return all names:
 
- get_display_resolution_name(size => "1280x720", all => 1); # -> ["720p", "HD", "WXGA 16:9"]
+ get_display_resolution_name(size => "1280x720", all => 1); # -> [200, "OK", ["720p", "HD", "WXGA 16:9"], {}]
 
 =item * Unknown resolution size:
 
- get_display_resolution_name(size => "999x666"); # -> undef
+ get_display_resolution_name(size => "999x666"); # -> [200, "OK", undef, {}]
 
 =back
 
@@ -358,7 +381,11 @@ When set to true, an arrayref will be returned instead of string.
 Return value:  (str|array[str])
 
 
-=head2 get_display_resolution_size(%args) -> str
+=head2 get_display_resolution_size
+
+Usage:
+
+ get_display_resolution_size(%args) -> str
 
 Get the size of a display resolution name.
 
@@ -368,11 +395,11 @@ Examples:
 
 =item * Example #1:
 
- get_display_resolution_size(name => "VGA"); # -> "640x480"
+ get_display_resolution_size(name => "VGA"); # -> [200, "OK", "640x480", {}]
 
 =item * Unknown name:
 
- get_display_resolution_size(name => "foo"); # -> undef
+ get_display_resolution_size(name => "foo"); # -> [200, "OK", undef, {}]
 
 =back
 
@@ -391,7 +418,11 @@ Arguments ('*' denotes required arguments):
 Return value:  (str)
 
 
-=head2 list_display_resolution_names() -> hash
+=head2 list_display_resolution_names
+
+Usage:
+
+ list_display_resolution_names() -> hash
 
 Examples:
 
@@ -403,65 +434,95 @@ Examples:
 
 Result:
 
- {
-   "1080p"      => "1920x1080",
-   "1440p"      => "2560x1440",
-   "16K"        => "15360x8640",
-   "16K UHD"    => "15360x8640",
-   "480p"       => "720x480",
-   "4K"         => "3840x2160",
-   "4K UHD"     => "3840x2160",
-   "576p"       => "720x576",
-   "5K"         => "5120x2880",
-   "720p"       => "1280x720",
-   "8K"         => "7680x4320",
-   "8K UHD"     => "7680x4320",
-   "Cinema 2K"  => "2048x1080",
-   "Cinema 4K"  => "4096x2160",
-   "DCI 2K"     => "2048x1080",
-   "DCI 4K"     => "4096x2160",
-   "DGA"        => "960x640",
-   "FHD"        => "1920x1080",
-   "Full HD"    => "1920x1080",
-   "FWVGA"      => "854x480",
-   "HD"         => "1280x720",
-   "HD+"        => "1600x900",
-   "HQVGA"      => "240x160",
-   "HVGA"       => "480x320",
-   "qHD"        => "960x540",
-   "QHD"        => "2560x1440",
-   "QHD+"       => "3200x1800",
-   "QQVGA"      => "160x120",
-   "qqVGA"      => "160x120",
-   "QVGA"       => "320x240",
-   "SD"         => "640x480",
-   "SVGA"       => "800x600",
-   "SXGA"       => "1280x1024",
-   "UHD 16K"    => "15360x8640",
-   "UHD 4K"     => "3840x2160",
-   "UHD 8K"     => "7680x4320",
-   "UHD+"       => "5120x2880",
-   "UHDTV-1"    => "3840x2160",
-   "UHDTV-2"    => "7680x4320",
-   "UVGA"       => "800x600",
-   "UWQHD"      => "3440x1440",
-   "UXGA"       => "1600x1200",
-   "VGA"        => "640x480",
-   "WGA"        => "768x480",
-   "WQHD"       => "2560x1440",
-   "WQVGA"      => "400x240",
-   "WQXGA"      => "2560x1600",
-   "WQXGA+"     => "3200x1800",
-   "WSVGA"      => "1024x600",
-   "WUXGA"      => "1920x1200",
-   "WVGA"       => "768x480",
-   "WXGA 16:10" => "1280x800",
-   "WXGA 16:9"  => "1280x720",
-   "WXGA 5:3"   => "1280x768",
-   "WXGA+"      => "1440x900",
-   "XGA"        => "1024x768",
-   "XGA+"       => "1152x864",
- }
+ [
+   200,
+   "OK",
+   {
+     "1080p"      => "1920x1080",
+     "1440p"      => "2560x1440",
+     "16K"        => "15360x8640",
+     "16K UHD"    => "15360x8640",
+     "2160p"      => "3840x2160",
+     "4320p"      => "7680x4320",
+     "480p"       => "720x480",
+     "4K"         => "3840x2160",
+     "4K UHD"     => "3840x2160",
+     "4K UHD-1"   => "3840x2160",
+     "576p"       => "720x576",
+     "5K"         => "5120x2880",
+     "720p"       => "1280x720",
+     "8K"         => "7680x4320",
+     "8K UHD"     => "7680x4320",
+     "8K UHD-2"   => "7680x4320",
+     "CGA1"       => "320x200",
+     "CGA2"       => "640x200",
+     "Cinema 2K"  => "2048x1080",
+     "Cinema 4K"  => "4096x2160",
+     "DCI 2K"     => "2048x1080",
+     "DCI 4K"     => "4096x2160",
+     "DGA"        => "960x640",
+     "DVGA"       => "960x640",
+     "EGA"        => "640x350",
+     "FHD"        => "1920x1080",
+     "Full HD"    => "1920x1080",
+     "FWVGA"      => "854x480",
+     "HD"         => "1280x720",
+     "HD+"        => "1600x900",
+     "HGC"        => "720x348",
+     "HQVGA"      => "240x160",
+     "HSXGA"      => "5120x4096",
+     "HUXGA"      => "6400x4800",
+     "HVGA"       => "480x320",
+     "HXGA"       => "4096x3072",
+     "MCGA"       => "640x480",
+     "MDA"        => "720x350",
+     "qHD"        => "960x540",
+     "QHD"        => "2560x1440",
+     "QHD+"       => "3200x1800",
+     "qqVGA"      => "160x120",
+     "QQVGA"      => "160x120",
+     "qSVGA"      => "400x300",
+     "QSXGA+"     => "2800x2100",
+     "QUXGA"      => "3200x2400",
+     "QVGA"       => "320x240",
+     "SD"         => "640x480",
+     "SVGA"       => "800x600",
+     "SXGA"       => "1280x1024",
+     "UHD 16K"    => "15360x8640",
+     "UHD 4K"     => "3840x2160",
+     "UHD 8K"     => "7680x4320",
+     "UHD+"       => "5120x2880",
+     "UHDTV-1"    => "3840x2160",
+     "UHDTV-2"    => "7680x4320",
+     "UVGA"       => "800x600",
+     "UW10K"      => "10240x4320",
+     "UW4K"       => "3840x1600",
+     "UW5K"       => "5120x2160",
+     "UWQHD"      => "3440x1440",
+     "UXGA"       => "1600x1200",
+     "VGA"        => "640x480",
+     "WGA"        => "768x480",
+     "WHSXGA"     => "6400x4096",
+     "WHUXGA"     => "7680x4800",
+     "WHXGA"      => "5120x3200",
+     "WQHD"       => "2560x1440",
+     "WQSXGA"     => "3200x2048",
+     "WQUXGA"     => "3840x2400",
+     "WQVGA"      => "400x240",
+     "WQXGA"      => "2560x1600",
+     "WQXGA+"     => "3200x1800",
+     "WSVGA"      => "1024x600",
+     "WUXGA"      => "1920x1200",
+     "WVGA"       => "768x480",
+     "WXGA 16:10" => "1280x800",
+     "WXGA 16:9"  => "1280x720",
+     "WXGA 5:3"   => "1280x768",
+     "WXGA+"      => "1440x900",
+     "XGA"        => "1024x768",
+     "XGA+"       => "1152x864",
+   },
+   {},
+ ]
 
 =back
 
@@ -487,13 +548,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<https://en.wikipedia.org/wiki/Display_resolution>
+
+L<https://en.wikipedia.org/wiki/List_of_common_resolutions>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
